Boldsign.Document (Boldsign v0.6.1)

Copy Markdown View Source

BoldSign Document API.

Summary

Functions

Adds recipient authentication to a document.

Adds tags to a document.

Lists documents sent on behalf of or by other senders.

Cancels editing for a document.

Changes a signer's access code.

Changes a document recipient.

Creates a document draft.

Creates an embedded edit URL for a document.

Creates an embedded request URL.

Deletes tags from a document.

Sends a draft document for signature.

Edits a document.

Extends a document's expiry.

Gets the properties of a document.

Lists documents.

Reminds signers about a document.

Removes recipient authentication from a document.

Sends a document for signature.

Lists team documents.

Functions

add_authentication(client, document_id, params)

Adds recipient authentication to a document.

add_tags(client, params)

Adds tags to a document.

behalf_list(client, params \\ [])

Lists documents sent on behalf of or by other senders.

cancel_editing(client, document_id, params \\ [])

Cancels editing for a document.

change_access_code(client, document_id, params)

Changes a signer's access code.

change_recipient(client, document_id, params)

Changes a document recipient.

create(client, params)

Creates a document draft.

create_embedded_edit_url(client, document_id, params \\ %{})

Creates an embedded edit URL for a document.

create_embedded_request_url(client, params)

Creates an embedded request URL.

delete(client, document_id, params \\ [])

Deletes a document.

delete_tags(client, params)

Deletes tags from a document.

download(client, document_id, params \\ [])

Downloads a document.

download_attachment(client, document_id, attachment_id, params \\ [])

Downloads a document attachment.

download_audit_log(client, document_id, params \\ [])

Downloads a document audit log.

draft_send(client, document_id)

Sends a draft document for signature.

edit(client, params)

Edits a document.

edit(client, document_id, params)

extend_expiry(client, document_id, params)

Extends a document's expiry.

get_embedded_sign_link(client, document_id, params \\ [])

Creates an embedded signing link.

get_properties(client, document_id)

Gets the properties of a document.

list(client, params \\ [])

Lists documents.

prefill_fields(client, document_id, params)

Prefills document fields.

remind(client, document_id, params \\ %{})

Reminds signers about a document.

remove_authentication(client, document_id, params)

Removes recipient authentication from a document.

revoke(client, document_id, params \\ %{})

Revokes a document.

send(client, params)

Sends a document for signature.

Supports two modes:

  • JSON (default): params are sent as JSON, including :fileUrls.
  • Multipart (:files): when non-empty Boldsign.File tuples are passed, the request is sent as multipart form data with files + JSON-stringified param fields (matching BoldSign's official SDK conventions).

team_list(client, params \\ [])

Lists team documents.