BoldSign Document API.
Summary
Functions
Adds recipient authentication to a document.
Adds tags to a document.
Lists documents sent on behalf of or by other senders.
Cancels editing for a document.
Changes a signer's access code.
Changes a document recipient.
Creates a document draft.
Creates an embedded edit URL for a document.
Creates an embedded request URL.
Deletes a document.
Deletes tags from a document.
Downloads a document.
Downloads a document attachment.
Downloads a document audit log.
Sends a draft document for signature.
Edits a document.
Extends a document's expiry.
Creates an embedded signing link.
Gets the properties of a document.
Lists documents.
Prefills document fields.
Reminds signers about a document.
Removes recipient authentication from a document.
Revokes a document.
Sends a document for signature.
Lists team documents.
Functions
Adds recipient authentication to a document.
Adds tags to a document.
Lists documents sent on behalf of or by other senders.
Cancels editing for a document.
Changes a signer's access code.
Changes a document recipient.
Creates a document draft.
Creates an embedded edit URL for a document.
Creates an embedded request URL.
Deletes a document.
Deletes tags from a document.
Downloads a document.
Downloads a document attachment.
Downloads a document audit log.
Sends a draft document for signature.
Edits a document.
Extends a document's expiry.
Creates an embedded signing link.
Gets the properties of a document.
Lists documents.
Prefills document fields.
Reminds signers about a document.
Removes recipient authentication from a document.
Revokes a document.
Sends a document for signature.
Supports two modes:
- JSON (default): params are sent as JSON, including
:fileUrls. - Multipart (
:files): when non-emptyBoldsign.Filetuples are passed, the request is sent as multipart form data with files + JSON-stringified param fields (matching BoldSign's official SDK conventions).
Lists team documents.